{
    "$graph": [
        {
            "class": "Workflow",
            "label": "running cellranger mkfastq and count",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#main/bcl_directory"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/chemistry"
                },
                {
                    "type": "Directory",
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": "File",
                    "id": "#main/simple_sample_csv"
                }
            ],
            "steps": [
                {
                    "run": "#cellranger_count.cwl",
                    "in": [
                        {
                            "source": "#main/chemistry",
                            "id": "#main/count/chemistry"
                        },
                        {
                            "source": "#main/mkfastq/fastq_dir",
                            "id": "#main/count/fastq_directory"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/count/reference"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/count/sample_name"
                        }
                    ],
                    "out": [
                        "#main/count/out_dir"
                    ],
                    "id": "#main/count"
                },
                {
                    "run": "#cellranger_mkfastq.cwl",
                    "in": [
                        {
                            "source": "#main/bcl_directory",
                            "id": "#main/mkfastq/bcl_directory"
                        },
                        {
                            "source": "#main/simple_sample_csv",
                            "id": "#main/mkfastq/simple_sample_csv"
                        }
                    ],
                    "out": [
                        "#main/mkfastq/samplesheet_csv",
                        "#main/mkfastq/fastq_dir"
                    ],
                    "id": "#main/mkfastq"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/count/out_dir",
                    "id": "#main/counts_out_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/mkfastq/fastq_dir",
                    "id": "#main/fastqs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mkfastq/samplesheet_csv",
                    "id": "#main/samplesheet"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Run Cell Ranger Count",
            "baseCommand": [
                "/opt/cellranger-3.0.1/cellranger",
                "count",
                "--localmem=64",
                "--localcores=8",
                "--id=cellranger_output"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gsc.wustl.edu/mgi/cellranger:3.0.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 64000,
                    "coresMin": 8
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--chemistry=",
                        "position": 1,
                        "separate": false
                    },
                    "default": "auto",
                    "doc": "Assay configuration used, default 'auto' should usually work without issue",
                    "id": "#cellranger_count.cwl/chemistry"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--fastqs=",
                        "position": 2,
                        "separate": false
                    },
                    "doc": "Directory containing fastq files",
                    "id": "#cellranger_count.cwl/fastq_directory"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--transcriptome=",
                        "position": 3,
                        "separate": false
                    },
                    "doc": "Transcriptome reference compatible with input species and Cell Ranger",
                    "id": "#cellranger_count.cwl/reference"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--sample=",
                        "position": 4,
                        "separate": false
                    },
                    "doc": "Sample name, must be same as name specified in sample sheet in previous mkfastq step",
                    "id": "#cellranger_count.cwl/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "cellranger_output/outs/"
                    },
                    "id": "#cellranger_count.cwl/out_dir"
                }
            ],
            "id": "#cellranger_count.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Run Cell Ranger mkfastq",
            "baseCommand": [
                "/opt/cellranger-3.0.1/cellranger",
                "mkfastq",
                "--localmem=64",
                "--localcores=8",
                "--id=cellranger_output"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gsc.wustl.edu/mgi/cellranger:3.0.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 64000,
                    "coresMin": 8
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--run=",
                        "position": 1,
                        "separate": false
                    },
                    "doc": "Directory of the Illumina BCL run",
                    "id": "#cellranger_mkfastq.cwl/bcl_directory"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--simple-csv=",
                        "position": 3,
                        "separate": false
                    },
                    "doc": "input simple sample CSV used to describe the way to demultiplex the flowcell",
                    "id": "#cellranger_mkfastq.cwl/simple_sample_csv"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "cellranger_output/outs/fastq_path/"
                    },
                    "id": "#cellranger_mkfastq.cwl/fastq_dir"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cellranger_output/outs/input_samplesheet.csv"
                    },
                    "id": "#cellranger_mkfastq.cwl/samplesheet_csv"
                }
            ],
            "id": "#cellranger_mkfastq.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
